@@ -709,9 +709,6 @@ module Debian
       l
     end
     def Archives.parse(f,&block)
-      unless @file
-	@file = []
-      end
       l = {}
       f.each("\n\n") {|info|
 	d = yield info
@@ -723,6 +720,10 @@ module Debian
       }
       l
     end
+    def initialized()
+      @file = []
+      @lists = {}
+    end
     attr_reader :file, :lists
     def to_s() @file.join("+"); end
     
@@ -873,13 +874,17 @@ module Debian
     
     def [](package) @lists[package]; end
     def package(package) @lists[package]; end
+
+    def pkgs_re_escape(pkgs)
+      return pkgs.map{|p| Regexp.escape(p)}.join('|')
+    end
   end
 
   ################################################################
   class Sources < Archives
     def initialize(file = "", pkgs = [], fields = [])
       unless pkgs.empty?
-	pkgre = Regexp.new("(Package|Source):\\s(#{pkgs.join('|')})\n")
+	pkgre = Regexp.new("(Package|Source):\\s(#{pkgs_re_escape(pkgs)})\n")
       end
       @lists = Archives.parseArchiveFile(file) {|info|
 	if !pkgre || pkgre =~ info
@@ -897,7 +902,7 @@ module Debian
   class Packages < Archives
     def initialize(file = "", pkgs = [], fields = [])
       unless pkgs.empty?
-	pkgre = Regexp.new("Package:\\s(#{pkgs.join('|')})\n")
+	pkgre = Regexp.new("Package:\\s(#{pkgs_re_escape(pkgs)})\n")
       end
       @provides = {}
       @file = [file]
